cdist-type__iptables_apply(7)
=============================

NAME
----
cdist-type__iptables_apply - Apply the rules


DESCRIPTION
-----------
This cdist type deploys an init script that triggers
the configured rules and also re-applies them on
configuration.


REQUIRED PARAMETERS
-------------------
None

OPTIONAL PARAMETERS
-------------------
None

EXAMPLES
--------

None (__iptables_apply is used by __iptables_rule)


SEE ALSO
--------
:strong:`cdist-type__iptables_rule`\ (7), :strong:`iptables`\ (8)


AUTHORS
-------
Nico Schottelius <nico-cdist--@--schottelius.org>


COPYING
-------
Copyright \(C) 2013 Nico Schottelius. You can redistribute it
and/or modify it under the terms of the GNU General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.
